@@ -1,4 +1,4 @@
-/* This file is part of the KDE libraries
+/* This file is part of the dbusmenu-qt library
    Copyright 2009 Canonical
    Author: Aurelien Gateau <aurelien.gateau@canonical.com>
 
@@ -32,8 +32,6 @@
 #include <QSignalMapper>
 #include <QTime>
 #include <QTimer>
-#include <QToolButton>
-#include <QWidgetAction>
 
 // Local
 #include "dbusmenuitem_p.h"
@@ -43,6 +41,7 @@
 
 //#define BENCHMARK
 #ifdef BENCHMARK
+#include <QTime>
 static QTime sChrono;
 #endif
 
@@ -67,29 +66,6 @@ struct Task
     DBusMenuImporterMethod m_method;
 };
 
-class EventSniffer : public QObject
-{
-public:
-    EventSniffer(QObject *parent = 0)
-        : QObject(parent) { }
-
-    ~EventSniffer() { }
-
-    bool eventFilter(QObject *object, QEvent *event)
-    {
-        Q_UNUSED(object);
-
-        if (event->type() == QEvent::Paint ||
-            event->type() == QEvent::KeyPress ||
-            event->type() == QEvent::KeyRelease) {
-            return false;
-        }
-
-        event->accept();
-        return true;
-    }
-};
-
 class DBusMenuImporterPrivate
 {
 public:
@@ -167,29 +143,8 @@ public:
                 group->addAction(action);
             }
         }
-
-        bool isMenuTitle = map.take("x-kde-title").toBool();
-
         updateAction(action, map, map.keys());
 
-        if (isMenuTitle) {
-            QAction *buttonAction = action;
-            QFont font = buttonAction->font();
-            font.setBold(true);
-            buttonAction->setFont(font);
-            buttonAction->setEnabled(true);
-
-            QWidgetAction *action = new QWidgetAction(parent);
-            action->setObjectName("kmenu_title");
-            QToolButton *titleButton = new QToolButton(0);
-            EventSniffer *eventSniffer = new EventSniffer(titleButton);
-            titleButton->installEventFilter(eventSniffer); // prevent clicks on the title of the menu
-            titleButton->setDefaultAction(buttonAction);
-            titleButton->setDown(true); // prevent hover style changes in some styles
-            titleButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
-            action->setDefaultWidget(titleButton);
-        }
-
         return action;
     }
 
